pub struct PostageContext { /* private fields */ }Expand description
Context for postage validation.
Contains the current state needed to determine whether batches are expired or usable. This data may come from a blockchain, database, or any other source.
Implementations
Sourceimpl PostageContext
impl PostageContext
Sourcepub const fn total_amount(&self) -> u128
pub const fn total_amount(&self) -> u128
Returns the cumulative payout per chunk.
Sourcepub const fn set_total_amount(&mut self, total_amount: u128)
pub const fn set_total_amount(&mut self, total_amount: u128)
Updates the total amount.