pub fn current_timestamp() -> u64Expand description
Returns the current timestamp in nanoseconds since the Unix epoch.
This is used when creating stamps to record when they were issued.
In no_std environments, this returns 0 and callers should provide
timestamps via other means (e.g., prepare_stamp with explicit timestamp).